# MapAttributesAnswerResult

The result of the attribute mapping. Any successfully mapped attributes will be contained in `mapped_attributes`. Any that failed will not be present. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**mapped_attributes** | [**MappedAttributes**](MappedAttributes.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


